<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;مؤرشف لكسكيوتي&lt;/span&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>مؤ رشف ملفات بسيط محايد لسطح المكتب لديك، مبنيّ على كيوتي</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>المؤلفون</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>البرمجة:
* Hong Jen Yee ‏(PCMan) ‏&lt;pcman.tw@gmail.com&gt;

اشتُّق «مؤرشف لكسكيوتي» من البرامج الآتية:
* «إنغرمبا» لسطح المكتب متّة
* «ضاغط الملفات» لسطح المكتب جنوم
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>الرخصة</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>أرشيفي LXQt

حقوق النشر (C) 2020 فريق LXQt

هذا البرنامج هو برنامج مجاني. يمكنك إعادة توزيعه و / أو
تعديله بموجب شروط رخصة جنو العمومية العامة
كما نشرته مؤسسة البرمجيات الحرة ؛ إما الإصدار 2
من الترخيص ، أو (حسب اختيارك) أي إصدار لاحق.

يتم توزيع هذا البرنامج على أمل أن يكون مفيدًا ،
ولكن دون أي ضمان ؛ حتى بدون الضمان الضمني لـ
القابلية للتسويق أو الملاءمة لغرض معين. انظر
رخصة جنو العمومية لمزيد من التفاصيل.

يجب أن تكون قد تلقيت نسخة من رخصة جنو العمومية
جنبا إلى جنب مع هذا البرنامج ؛ إذا لم يكن كذلك ، فاكتب إلى البرمجيات الحرة
Foundation، Inc.، 51 Franklin Street، Fifth Floor، Boston، MA 02110-1301، USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>نوع الأرشيف غير مدعوم.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*ملفات %1 (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>كل النسق المدعومة</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>فشل تنفيذ الأمر.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>الأمر غير موجود.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>خرج الأمر بشكل غير طبيعي.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>كلمة السر مطلوبة.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>ثمّة قسم ناقص.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>طقم المحارف سيّئ.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>نسق الملفات غير مدعوم.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>حدثت أخطاء مجهولة.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation> ميكا.بايت</translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>افصل إلى أقسام بحجم</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>كلمة المرور:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>قم بتشفير قائمة الملفات أيضًا</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="12"/>
        <source>Create Archive</source>
        <translation>إنشاء أرشيف</translation>
    </message>
    <message>
        <location filename="../createfiledialog.cpp" line="14"/>
        <source>All files (*)</source>
        <translation>كل الملفات (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>استخرج</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>&amp;استخرج كل الملفات</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>&amp;استخرج الملفات المحدّدة</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>إجراءات</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>أعِد إنشاء المجلدات</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>الكتابة فوق الملفات الموجودة</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>لا تستخرج الملفات القديمة</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="11"/>
        <source>Extract</source>
        <translation>استخرج</translation>
    </message>
    <message>
        <location filename="../extractfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>كل الملفات (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>File Archiver</source>
        <translation>مؤ رشف الملفات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>رشّح الملفات…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;ملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;تحرير</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;View</source>
        <translation>&amp;منظور</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>&amp;Icon Size</source>
        <translation>&amp;حجم الأيقونة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&amp;Help</source>
        <translation>&amp;مساعدة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Main Toolbar</source>
        <translation>شريط الأدوات الرئيسي</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>&amp;About</source>
        <translation>&amp;عن</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>&amp;New</source>
        <translation>&amp;جديد</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>&amp;Open</source>
        <translation>&amp;افتح</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="213"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Save &amp;As</source>
        <translation>&amp;احفظ كَ‍</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Extract</source>
        <translation>&amp;استخرج</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;Test</source>
        <translation>&amp;اختبر</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>&amp;Properties</source>
        <translation>&amp;الخصائص</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="252"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>&amp;Close</source>
        <translation>&amp;أغلِق</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>Cu&amp;t</source>
        <translation>&amp;قصّ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>&amp;Copy</source>
        <translation>&amp;انسخ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>&amp;Paste</source>
        <translation>&amp;ألصِق</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>&amp;Rename</source>
        <translation>&amp;غيّر الاسم</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="317"/>
        <source>&amp;Delete</source>
        <translation>&amp;احذف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>&amp;Select All</source>
        <translation>&amp;حدّد الكل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>&amp;Find</source>
        <translation>&amp;ابحث</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>&amp;Add Files</source>
        <translation>&amp;أضِف ملفات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Add F&amp;older</source>
        <translation>&amp;أضِف مجلداً</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>Pass&amp;word</source>
        <translation>&amp;كلمة المرور</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="373"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;شريط الأدوات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;شريط الحالة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;شجرة الأدلة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="406"/>
        <source>S&amp;how as Folder</source>
        <translation>&amp;اعرض كمجلد</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Show &amp;All Files</source>
        <translation>&amp;اعرض كل الملفات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>St&amp;op</source>
        <translation>&amp;قِف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Esc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>&amp;Reload</source>
        <translation>&amp;أعِد التحميل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Filename &amp;Encoding</source>
        <translation>&amp;ترميز اسم الملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;اعرض العناصر المحدّدة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Filter</source>
        <translation>&amp;رشّح</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>&amp;Expand</source>
        <translation>&amp;وسّع</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>&amp;Collapse</source>
        <translation>&amp;اطوِ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>16 px</source>
        <translation>16 بكسل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>24 px</source>
        <translation>24 بكسل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>32 px</source>
        <translation>32 بكسل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>48 px</source>
        <translation>48 بكسل</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <location filename="../mainwindow.cpp" line="397"/>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>All files (*)</source>
        <translation>كل الملفات (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Add only if &amp;newer</source>
        <translation>&amp;أضِف لو كانت أحدث فقط</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Confirm</source>
        <translation>تأكيد</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>أمتأكّد من حذف الملفات المحدّدة؟</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="754"/>
        <source>Version: %1</source>
        <translation>الإصدار: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Success</source>
        <translation>نجح</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>No errors have been found.</source>
        <translation>لم توجد أيّ أخطاء.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="923"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Add Files</source>
        <translation>إضافة ملفات</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Add Folder</source>
        <translation>إضافة مجلد</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>N/A</source>
        <translation>غير مُتاحة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>Uncompressed Size:</source>
        <translation>الحجم بلا ضغط:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1014"/>
        <source>Compression Ratio:</source>
        <translation>نسبة الضغط:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1033"/>
        <source>Link to</source>
        <translation>رابط إلى</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1072"/>
        <source>File name</source>
        <translation>اسم الملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1073"/>
        <source>File Type</source>
        <translation>نوع الملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>File Size</source>
        <translation>حجم الملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Modified</source>
        <translation>تاريخ التعديل</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1076"/>
        <source>Encrypted</source>
        <translation>التعمية</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1102"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>ملف</numerusform>
            <numerusform>%n ملف</numerusform>
            <numerusform>ملفان</numerusform>
            <numerusform>%n ملفات</numerusform>
            <numerusform>%n ملفات</numerusform>
            <numerusform>%n ملفات</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>عمِّ قائمة الملفات أيضًا</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>اعرض كلمة المرور</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>كلمة المرور:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt; &lt;b&gt; ملاحظة: &lt;/b&gt; سيتم استخدام كلمة المرور لتشفير الملفات التي تضيفها إلى الأرشيف الحالي ، وفك تشفير الملفات التي تستخرجها من الأرشيف الحالي. عندما يتم إغلاق الأرشيف ، سيتم حذف كلمة المرور. &lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>التقدّم</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation>%p ‏٪</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7‎-Zip ‏(.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>ضغط 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation>Ace ‏(.ace)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation>Ar ‏(.a)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation>Ar ‏(.ar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation>Arj ‏(.arj)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>ضغط bzip (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>ضغط bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation>Cabinet ‏(.cab)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar أرشيف Comic Book (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip أرشيف Comic Book (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>للضغط بواسطة gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation>نوع ‏(.ear)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>ملف zip يستخرج نفسه بنفسه (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation>Jar ‏(.jar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation>Lha ‏(.lzh)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation>Lrzip ‏(.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar مضغوط lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar مضغوط lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar مضغوط lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar مضغوط lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>نسق صور وِندوز (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation>Rar ‏(.rar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar مضغوط (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar مضغوط (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation>War ‏(.war)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation>Xz ‏(.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tarمضغوط xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar ضغط with zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation>Zoo ‏(.zoo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation>Zip ‏(.zip)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>يُضيف الملف: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>يستخرج الملف: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>يُزيل الملف: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>يحذف الملفات من الأرشيف</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>يُعيد ضغط الأرشيف</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>يفكّ ضغط الأرشيف</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>لم يوجد الملف.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>نوع الأرشيف غير مدعوم.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>لم يوجد الأرشيف</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>ليس لديك الأذونات الصحيحة.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>لا يمكن تعديل نوع هذا الأرشيف</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>لا يمكنك إضافة أرشيف داخل نفسه.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>تعذّر العثور على القسم: %s</translation>
    </message>
</context>
</TS>
